("A modifier" "A-vaihtonppin")
("GNU" "GNU")
("H modifier" "H-vaihtonppin")
("LaTeX" "LaTeX")
("M modifier" "M-vaihtonppin")
("TeX" "TeX")
("abbreviation" "lyhenne")
("about" "tietoja")
("about menu" "tietoja-menu")
("above" "ylpuolelle")
("abstract" "tiivistelm")
("accent" "aksentti")
("accept" "hyvksy")
("accept all scripts" "hyvksy kaikki skriptit")
("accept no scripts" "l hyvksy skriptej")
("accept script" "hyvksy skripti")
("acknowledgment" "kiitokset")
("acronym" "akronyymi")
("action" "toiminto")
("activate" "aktivoi")
("acute" "acute")
("add switch after" "lis valitsin jlkeen")
("add switch before" "lis valitsin ennen")
("address" "osoite")
("address block" "osoitelohko")
("advanced" "edistynyt")
("advanced layout features" "edistyneet asetteluominaisuudet")
("after" "jlkeen")
("algorithm" "algoritmi")
("align cell to the bottom" "tasaa solu alareunaan")
("align cell to the left" "tasaa solu vasemmalle")
("align cell to the right" "tasaa solu oikealle")
("align cell to the top" "tasaa solu ylreunaan")
("align table at base of left column" "tasaa taulukko vasemman sarakkeen alareunaan")
("align table at base of middle column" "tasaa taulukko keskimmisen sarakkeen alareunaan")
("align table at base of origin column" "tasaa taulukko sarakkeen alareunaan")
("align table at base of right column" "tasaa taulukko oikeanpuoleisen sarakkeen alareunaan")
("align table at fraction bar height" "tasaa taulukko murtolukuviivan korkeudelle")
("align table at the base of bottom row" "tasaa taulukko alimmaisen rivin alareunaan")
("align table at the base of middle row" "tasaa taulukko keskimmisen rivin alareunaan")
("align table at the base of origin row" "tasaa taulukko rivin alareunaan")
("align table at the base of top row" "tasaa taulukko ylimmisen rivin alareunaan")
("align table at the bottom" "tasaa taulukko alareunaan")
("align table at the center" "tasaa taulukko keskelle")
("align table at the horizontal center" "tasaa taulukko keskelle horisontaalisesti")
("align table at the left" "tasaa taulukko vasemmalle")
("align table at the top" "tasaa taulukko ylreunaan")
("align table to the right" "tasaa taulukko oikealle")
("align text to the left" "tasaa teksti vasemmalle")
("align text to the right" "tasaa teksti oikealle")
("alignment" "tasaus")
("all" "kaikki")
("allow" "salli")
("allowed extension" "sallittu laajennus")
("allowed reduction" "sallittu reduktio")
("alpha release" "alfa-versio")
("alt key" "alt-nppin")
("and" "ja")
("appendix" "liite")
("apply" "sovella")
("april" "huhtikuu")
("arab" "arabi")
("archaic" "arkaainen")
("architecture" "arkkitehtuuri")
("argument" "argumentti")
("arithmetic" "aritmetiikka")
("armenian" "armenia")
("arrow" "nuoli")
("arrows" "nuolin")
("article" "artikkeli")
("as on paper" "kuin paperilla")
("assign" "assign")
("at fraction bar height" "murtolukuviivan korkeudelle")
("at the baseline" "perusviivalle")
("at the bottom" "alareunaan")
("at the left" "vasemmalle")
("at the middle" "keskelle")
("at the right" "oikealle")
("at the top" "ylreunaan")
("attach" "liit")
("attach buffer to which project" "mihin projektiin puskuri liitetn")
("august" "elokuu")
("author" "tekij")
("authorize" "salli")
("automatic" "automaattinen")
("automatically generated content" "automaattisesti generoitu teksti")
("axiom" "aksiooma")
("background" "tausta")
("background color" "taustavri")
("backward replace" "korvaa taaksepin")
("backward search" "etsi taaksepin")
("bad data format" "vr dataformaatti")
("bar" "viiva")
("bard" "bardi")
("base level" "perustaso")
("bashkirian" "bashkirian")
("basic" "perus")
("basic data types" "perusdatatyypit")
("basic types" "perustyypit")
("be useful" "olla hydyllinen")
("become a TeXmacs developer" "ala TeXmacsin kehittjksi")
("before" "ennen")
("begin" "aloita")
("below" "alapuolelle")
("beta release" "beta-versio")
("bibliography" "kirjallisuutta")
("bibliography file" "kirjallisuusviitetiedosto")
("bibliography style" "kirjallisusviitteiden tyylitiedosto")
("big" "suuri")
("big figure" "suuri kuva")
("big operator" "suuri operaattori")
("big skip" "suuri vli")
("big table" "suuri taulukko")
("binary operation" "kaksipaikkainen operaattori")
("binary relation" "kaksipaikkainen relaatio")
("black" "musta")
("blackboard bold" "blackboard bold")
("blackboard math" "blackboard matematiikka")
("blackletter" "blackletter")
("blue" "sininen")
("body" "runko")
("bold" "lihavoitu")
("book" "kirja")
("border" "reunus")
("both" "molemmat")
("bottom" "pohja")
("bottom border" "alareuna")
("bottom margin" "alareunus")
("bottom padding" "alatytt")
("branch" "haaraudu")
("break" "rivin- tai sivunvaihto")
("breaking" "sivunvaihto")
("breve" "kaari")
("british" "britti")
("brown" "ruskea")
("browse" "selaa")
("browse web" "selaa www:t")
("browser" "selain")
("buffer" "puskuri")
("bullet" "luettelomerkki")
("bullets" "palloin")
("by" " ")
("by typing" "kirjoittamalla")
("bytes free" "tavua vapaana")
("bytes used" "tavua kytetty")
("calligraphic" "kalligrafinen")
("cancel" "peruuta")
("caps-lock key" "caps-lock-nppin")
("case" "case")
("cc" "cc")
("cell" "solu")
("cell background color" "solun taustavri")
("cell border" "solun reuna")
("cell height" "solun korkeus")
("cell operation mode" "komennot vaikuttavat")
("cell width" "solun leveys")
("center" "keskit")
("center text" "keskit teksti")
("centered" "keskitetty")
("centered block" "keskitetty lohko")
("centered tabular" "keskitetty taulukoitu")
("change border of cell" "vaihda solun reunusta")
("change cell operation mode" "vaihda solun toimintatilaa")
("change log" "muutosloki")
("changes" "muutokset")
("chapter" "luku")
("check" "vknen")
("check text for spelling errors" "tarkasta tekstin oikeinkirjoitus")
("chinese" "kiina")
("choice" "valinta")
("citation" "viite")
("cite" "viittaa")
("class" "luokka")
("clear" "tyhjenn")
("clear selection" "tyhjenn valinta")
("clipped" "leikattu")
("clipped and magnified" "leikattu ja suurennettu")
("clipped and resized" "leikattu ja pienennetty tai suurennettu")
("clone" "kloonaa")
("clone window" "kloonaa ikkuna")
("close" "sulje")
("close TeXmacs" "sulje TeXmacs")
("close buffer" "sulje puskuri")
("close session" "sulje istunto")
("close window" "sulje ikkuna")
("closing" "lopetus")
("code" "koodi")
("color" "vri")
("column" "sarake")
("column contains glued items" "sarakkeessa on liimattuja osia")
("compatibility with other formats" "yhteensopivuus muiden formaattien kanssa")
("compile article" "knn artikkeli")
("compile book" "knn kirja")
("compile buffer" "knn puskuri")
("compile project" "knn projekti")
("complex" "kompleksinen merkint")
("concrete" "concrete")
("condensed" "tiivistetty")
("condition" "ehto")
("configuration" "asetukset")
("content tag" "sislttagi")
("context dependent icons" "kontekstista riippuvat ikonit")
("continuation of" "jatke")
("convention" "tapa")
("converters to other data formats" "muuntaminen toiseen tiedostomuotoon")
("copy" "kopioi")
("copy text" "kopioi teksti")
("copy to" "kopioi")
("copying" "kopiointi")
("corollary" "korollaari")
("correct text" "korjaa teksti")
("cursors" "kursorit")
("custom tab" "kustomoitu tabulaattori")
("customizing TeXmacs" "TeXmacsin stminen")
("customizing the TeXmacs styles" "TeXmacsin tyylien stminen")
("custum tab" "virhe!")
("cut" "leikkaa")
("cut text" "leikkaa teksti")
("cut to" "leikkaa")
("cypriot" "kypros")
("cyrillic" "kyrillinen")
("cyrillic input method" "kyrillisen tekstin sytttapa")
("cyrillic italic right" "kyrillinen kursiivi oikealle")
("czech" "tsekki")
("dancers" "tanssijat")
("dash" "viiva")
("dashes" "viivoin")
("data conversion" "datan muuttaminen")
("data format" "dataformaatti")
("date" "pivmr")
("deactivate" "deaktivoi")
("deactivate table" "deaktivoi taulukko")
("december" "joulukuu")
("decorate atoms" "decorate atoms")
("default" "oletus")
("default padding" "oletustytt")
("definition" "mritelm")
("delete" "poista")
("delete column" "poista sarake")
("delete row" "poista rivi")
("denominator" "nimittj")
("description" "kuvaile")
("destination" "mrnp")
("detach" "irrota")
("determinant" "determinantti")
("devangari" "devangari")
("developers guide" "kehittjn opas")
("directory" "hakemisto")
("disable first indentation" "ota ensimminen sisennys pois kytst")
("disable first indentation after" "poista ensimminen sisennys jlkeen")
("disable first indentation before" "poista ensimminen sisennys ennen")
("disable indentation" "poista sisennys")
("disable indentation after" "poista sisennys jlkeen")
("disable indentation before" "poista sisennys ennen")
("disallow" "l salli")
("distribute unused space" "jaa kyttmtn tila")
("div" "div")
("document" "asiakirja")
("document format" "tallennusmuoto")
("document style" "asiakirjan tyyli")
("document styles" "asiakirjatyylit")
("documentation" "dokumentaatio")
("documents are trees" "asiakirjat ovat puita")
("dot" "piste")
("dots" "pisteet")
("double stroke" "ajatusviiva")
("down" "alas")
("dpi" "dpi")
("duplicate" "toistettu")
("dutch" "hollanti")
("dynamic libraries" "dynaamiset kirjastot")
("edit" "muokkaa")
("editing tools" "editointitykalut")
("email" "email")
("emphasize" "korosta")
("emphasize text" "korosta teksti")
("empty box" "tyhj laatikko")
("enable first indentation" "ota kyttn ensimminen sisennys")
("enable first indentation after" "ota kyttn ensimminen sisennys jlkeen")
("enable first indentation before" "ota kyttn ensimminen sisennys ennen")
("enable indentation" "ota sisennys kyttn")
("enable indentation after" "ota sisennys kyttn jlkeen")
("enable indentation before" "ota sisennys kyttn ennen")
("encl" "encl")
("end" "loppu")
("english" "englanti")
("enter a title" "syt otsikko")
("enumerate" "numeroi")
("enumerate|Alpha" "numeroi|Aakkosin")
("enumerate|Roman" "numeroi|Roomalaisin numeroin")
("enumerate|alpha" "numeroi|aakkosin")
("enumerate|roman" "numeroi|roomalaisin numeroin")
("env" "env")
("environment" "ymprist")
("epilogue" "epilogi")
("equal" "yhtkuin")
("equation" "yhtl")
("equations" "yhtlryhm")
("equivalent for" "ekvivalentti")
("error" "virhe")
("etruscan" "etruski")
("evaluate" "evaluoi")
("evaluate scheme expression" "evaluoi scheme-lauseke")
("even page footer" "parillisen sivun alatunniste")
("even page header" "parillisen sivun yltunniste")
("even page margin" "parillisen sivun marginaali")
("even page text" "parillisen sivun teksti")
("exact horizontal" "eksakti vaakasuora")
("exact mode" "eksakti tila")
("exam" "koe")
("example" "esimerkki")
("exclusive" "poissulkeva")
("exclusive or" "poissulkeva tai")
("executable" "suoritettava")
("execute" "suorita")
("execute a TeXmacs command" "suorita TeXmacs-komento")
("execute system command" "suorita systeemikomento")
("executive" "executive")
("exercise" "harjoitus")
("expand" "laajenna")
("explained" "selitetty")
("export" "tallenna muodossa")
("export as" "talleta muodossa")
("extend or normal" "laajennettu tai normaali")
("extern " "ulkoinen")
("extra" "ylimrinen")
("extract format" "talleta formaatti")
("family" "perhe")
("february" "helmikuu")
("figure" "kuva")
("file" "tiedosto")
("file name" "tiedostonimi")
("file not found" "tiedostoa ei lytynyt")
("find next match" "etsi seuraava")
("find text" "etsi tekstist")
("first contact" "ensimminen kontakti")
("first indentation" "ensimminen sisennys")
("first item" "ensimminen kohta")
("first page" "ensimminen sivu")
("first start" "ensimminen alku")
("flat" "lattana")
("flexibility" "joustavuus")
("flexibility factor for vertical spacing" "pystysuoran vlistyksen joustavuuskerroin")
("floating figure" "vapaasti asettuva kuva")
("floating object" "vapaasti asettuva objekti")
("floating table" "vapaasti asettuva taulukko")
("fold" "taite")
("folded" "taitettu")
("font" "kirjasintyyppi")
("font base size" "kirjasintyypin peruskoko")
("font dpi" "kirjasintyypin dpi")
("font family" "kirjasintyyppiperhe")
("font name" "kirjasintyypin nimi")
("font series" "kirjasintyypin sarja")
("font shape" "kirjasintyypin muoto")
("font size" "kirjasintyypin koko")
("font variant" "kirjasintyypin muunnelma")
("fonts" "kirjasintyypit")
("footer" "alatunniste")
("footnote" "alaviite")
("for" "sill")
("foreground" "edusta")
("foreign" "muut kielet")
("format" "muotoilu")
("formatted date" "muotoiltu pivmr")
("formula" "kaava")
("formula style" "kaavan tyyli")
("forward replace" "korvaa eteenpin")
("forward search" "etsi eteenpin")
("fraction" "murtoluku")
("french" "ranska")
("full manuals" "kokonaiset manuaalit")
("function" "funktio")
("further customization" "lis kustomointeja")
("future changes" "tulevia muutoksia")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs ei sisll minknlaista takuuta")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs on lisensoitu GNU:n yleisell lisenssill")
("general architecture of TeXmacs" "TeXmacsin yleinen arkkitehtuuri")
("general negation" "yleinen negaatio")
("generating font file" "generoin kirjasintiedostoja")
("generic" "yleinen")
("georgian" "georgia")
("german" "saksa")
("getting started" "aloittaminen")
("glossary" "sanasto")
("glossary entry" "sanastomerkint")
("glue" "liima")
("glue decorations" "lis koristeet")
("go" "siirry")
("gothic" "gothic")
("graphical interface" "graafinen kyttliittym")
("grave" "grave")
("greater" "suurempi")
("greater or equal" "suurempi tai yhtsuuri")
("greek" "kreikka")
("greek letter" "kreikkalainen kirjain")
("green" "vihre")
("grey" "harmaa")
("group" "ryhm")
("happy typing" "kirjoita hyvin")
("has been aborted" "on keskeytetty")
("has completed its task" "on suorittanut tehtvns")
("hat" "hattu")
("header" "yltunniste")
("header and footer" "yl- ja alatunniste")
("hebrew" "heprea")
("height" "korkeus")
("height is exactly the specified height" "korkeus on tsmlleen sama kuin on mritelty")
("height is maximum of specified height and box height" "korkeus on mritelmst ja laatikon korkeudesta suurempi")
("height is minimum of specified height and box height" "korkeus on mritelmst ja laatikon korkeudesta pienempi")
("height magnification" "korkeuden suurennos")
("help" "ohje")
("help me" "auta minua")
("help us" "auttaminen")
("here" "tss")
("home" "kotihakemisto")
("horizontal" "vaakasuora")
("horizontal cell alignment" "vaakasuora solun tasaus")
("horizontal ink separation" "vaakasuora mustevli")
("horizontal part" "vaakasuora osa")
("horizontal position" "vaakasuora paikka")
("horizontal space" "vaakasuora vli")
("horizontal table alignment" "taulukon tasaus vaakasuoraan")
("horizontally align cell to the base" "tasaa solu alareunaan vaakasuoraan")
("horizontally center the cell" "keskit solu vaakasuorassa suunnassa")
("how much longer may pages become" "kuinka paljon pidemmiksi sivut voivat tulla")
("how much shorter may pages become" "kuinka paljon lyhyemmiksi sivut voivat tulla")
("huge" "valtava")
("hungarian" "unkari")
("hyperlink" "hyperlinkki")
("hyphenation" "tavutus")
("icelandic" "islanti")
("if" "if")
("image" "kuva")
("image links" "kuvalinkit")
("implementation" "toteutus")
("import" "tuo muodossa")
("improving the current implementation" "tmnhetkisen toteutuksen parantaminen")
("inactive" "epaktiivinen")
("include" "sisllyt")
("include a document" "sisllyt asiakirja")
("include file" "sisllyt tiedosto")
("inclusion into TeXmacs" "TeXmacsiin sisllyttminen")
("inclusions" "sisllytetyt")
("indent" "sisenn")
("indentation flag" "sisennysasetus")
("index" "hakemisto")
("index entry" "hakemistomerkint")
("index level" "hakemistotaso")
("insert" "lis")
("insert Pr" "lis Pr")
("insert a TeXmacs symbol" "lis TeXmacs-symboli")
("insert a big operator" "lis suuri operaattori")
("insert a binary operation" "lis kaksipaikkainen operaattori")
("insert a binary relation" "lis kaksipaikkainen relaatio")
("insert a blackboard bold character" "lis blackboard bold kirjain")
("insert a bold calligraphic character" "lis lihavoitu kalligrafinen kirjain")
("insert a bold character" "lis lihavoitu kirjain")
("insert a calligraphic character" "lis kalligrafinen kirjain")
("insert a fraction" "lis murtoluku")
("insert a fraktur character" "lis fraktuurakirjain")
("insert a greek character" "lis kreikkalainen kirjain")
("insert a large left delimiter" "lis suuri vasemmanpuoleinen sulku")
("insert a large right delimiter" "lis suuri oikeanpuoleinen sulku")
("insert a large separator" "lis suuri erotin")
("insert a left subscript" "lis vasen alaindeksi")
("insert a link" "lis linkki")
("insert a miscellaneous symbol" "lis muu merkki")
("insert a new branch" "lis uusi haara")
("insert a new item" "lis uusi tietue")
("insert a picture" "sisllyt kuva")
("insert a square root" "lis nelijuuri")
("insert a table" "lis taulukko")
("insert a table or a matrix" "lis taulukko tai matriisi")
("insert an" "lis")
("insert an accent" "lis aksentti")
("insert an arrow" "lis nuoli")
("insert an environment" "lis ymprist")
("insert an n" "lis n")
("insert appendix" "lis liite")
("insert arccos" "lis arcuskosini")
("insert arcsin" "lis arcussini")
("insert arctan" "lis arcustangentti")
("insert arg" "lis argumentti")
("insert argument" "lis argumentti")
("insert automatically generated content" "lis automaattisesti luotua teksti")
("insert big contour integral" "lis suuri reitti-integraali")
("insert big coproduct" "lis suuri tulo")
("insert big direct sum" "lis suuri suora summa")
("insert big dotted point" "lis suuri pilkutettu piste")
("insert big integral" "lis suuri integraali")
("insert big intersection" "lis suuri leikkaus")
("insert big logical and" "lis suuri looginen ja")
("insert big logical or" "lis suuri looginen tai")
("insert big product" "lis suuri tulo")
("insert big square union" "lis suuri kulmikas unioni")
("insert big summation" "lis suuri summa")
("insert big tensor product" "lis suuri tensoritulo")
("insert big union" "lis suuri yhdiste")
("insert big union sum" "lis suuri yhdistesumma")
("insert big vertical space" "lis suuri pystysuora vli")
("insert chapter" "lis luku")
("insert column" "lis sarake")
("insert column to the left" "lis sarake vasemmalle")
("insert column to the right" "lis sarake oikealle")
("insert cos" "lis kosini")
("insert cosh" "lis hyperbolinen kosini")
("insert cot" "lis kotangentti")
("insert coth" "lis hyperbolinen kotangentti")
("insert csc" "lis kosekantti")
("insert deg" "lis aste")
("insert det" "lis det")
("insert dim" "lis dim")
("insert dollar" "lis dollari")
("insert equation" "lis yhtl")
("insert executable markup" "lis suoritettava merkkaus")
("insert exp" "lis exp")
("insert footnote" "lis alaviite")
("insert formula" "lis kaava")
("insert gcd" "lis gcd")
("insert hom" "lis hom")
("insert horizontal interword space" "lis vaakasuora sanavli")
("insert image" "lis kuva")
("insert inactive markup" "lis vuorovaikutteinen merkkaus")
("insert inf" "lis inf")
("insert ker" "lis ker")
("insert lg" "lis lg")
("insert lim" "lis lim")
("insert liminf" "lis liminf")
("insert limsup" "lis limsup")
("insert ln" "lis ln")
("insert log" "lis log")
("insert mathematics" "lis matematiikkaa")
("insert max" "lis max")
("insert medium horizontal space" "lis keskisuuri vaakasuora vli")
("insert medium vertical space" "lis keskisuuri pystysuora vli")
("insert min" "lis min")
("insert negative horizontal space" "lis negatiivinen vaakasuora vli")
("insert new item or number" "lis uusi kohta tai numero")
("insert new rows or columns" "lis uusia rivej tai sarakkeita")
("insert or delete rows or columns" "lis tai poista rivej tai sarakkeita")
("insert row" "lis rivi")
("insert row above" "lis rivi ylpuolelle")
("insert row below" "lis rivi alapuolelle")
("insert sec" "lis sekantti")
("insert section" "lis osio")
("insert sharp" "lis korotus")
("insert sin" "lis sini")
("insert sinh" "lis hyperbolinen sini")
("insert small horizontal space" "lis pieni vaakasuora vli")
("insert small vertical space" "lis pieni pystysuora vli")
("insert structural markup" "lis rakenteista merkkausta")
("insert subsection" "lis alaosio")
("insert subsubsection" "lis ala-alaosio")
("insert sup" "lis sup")
("insert tan" "lis tangentti")
("insert tanh" "lis hyperbolinen tangentti")
("insert thick horizontal space" "lis leve vaakasuora vli")
("interfacing" "liittminen")
("interfacing TeXmacs with other systems" "TeXmacsin liittminen muihin jrjestelmiin")
("interjection" "lisys")
("interline separation" "rivien erotus")
("interline space" "rivien vli")
("internationalization" "kntminen")
("interparagraph space" "kappaleiden vli")
("interrupt execution" "keskeyt suoritus")
("introduction" "johdanto")
("invisible" "nkymtn")
("invisible citation" "nkymtn viittaus")
("irish" "irlanti")
("is running" "on suorituksessa")
("is tuple" "on tuple")
("ispell does not respond" "ispell ei vastaa")
("ispell is already busy" "ispell on jo kytss")
("italian" "italia")
("italic" "kursiivi")
("italic right" "kursiivi oikealle")
("itemize" "luetteloi")
("january" "tammikuu")
("japanese" "japani")
("july" "heinkuu")
("june" "keskuu")
("justified" "tasattu")
("justify text" "tasaa teksti")
("key" "nppin")
("keyboard" "nppimist")
("keyboard equivalent" "vastine nppimistll")
("keyboard modifiers" "nppinmuuntimet")
("keyboard shortcut" "nppimistlyhenne")
("keymaps" "nppinkartat")
("keyword" "avainsana")
("keywords" "avainsanat")
("kill" "tapa")
("known bugs" "tunnetut bugit")
("label" "nimilappu")
("landscape" "vaakasuora")
("language" "kieli")
("large" "suuri")
("large closing bracket" "suuri oikea sulku")
("large delimiter" "suuri vlike")
("large opening bracket" "suuri vasen sulku")
("large separator" "suuri erotin")
("last page" "viimeinen sivu")
("latex command" "latex-komento")
("latin" "latin")
("layout" "asettelu")
("left" "vasen")
("left border" "vasen reuna")
("left margin" "vasen marginaali")
("left padding" "vasen tytt")
("left prime" "vasemmanpuoleinen ylpilkku")
("left aligned" "vasen reuna eptasainen")
("left slanted" "vasemmalle kalteva")
("left subscript" "vasemmanpuoleinen ylindeksi")
("left superscript" "vasemmanpuoleinen alaindeksi")
("left surrounding" "vasen ympriv")
("legal" "legal")
("lemma" "lemma")
("length" "pituus")
("less" "pienempi")
("less or equal" "pienempi tai yhtsuuri")
("letter" "kirje")
("license" "lisenssi")
("light" "kevyt")
("limitations" "rajoitukset")
("limits" "rajat")
("line" "rivi")
("line break" "rivinvaihto")
("line stretch" "rivin venytys")
("link" "linkki")
("link image" "lis linkki kuvaan")
("list" "lista")
("list of figures" "kuvat")
("list of tables" "taulukot")
("load" "avaa")
("load LaTeX file" "avaa LaTeX-tiedosto")
("load TeX file" "avaa TeX-tiedosto")
("load TeXmacs file" "avaa TeXmacs-tiedosto")
("load TeXmacs style file" "avaa TeXmacsin tyylitiedosto")
("load a file" "avaa tiedosto")
("load buffer" "avaa puskuri")
("load file" "avaa tiedosto")
("load html file" "avaa html-tiedosto")
("load image" "avaa kuva")
("load in new window" "avaa uuteen ikkunaan")
("load latex file" "avaa LaTeX-tiedosto")
("load more recent autosave file" "avaa uudempi automaattisesti talletettu tiedosto")
("load tex file" "avaa TeX-tiedosto")
("load verbatim file" "syt tiedosto muotoilemattomana")
("loaded" "ladattu")
("long" "pitk")
("look and feel" "ulkonk")
("look up" "look up")
("lower border" "alempi reuna")
("macro" "makro")
("magenta" "magenta")
("magic" "maaginen")
("magnification" "suurennus")
("magnified" "suurennettu")
("main" "pasiallinen")
("main icon bar" "pikonipalkki")
("major changes" "suuret muutokset")
("make a page insertion" "lis sivu")
("make a subscript" "lis alaindeksi")
("make a superscript" "lis ylindeksi")
("make acute" "tee karetti")
("make bar" "tee viiva")
("make check" "tarkista")
("make fraction" "tee murtoluku")
("make grave" "tee vakava")
("make hat" "tee hattu")
("make label" "tee nimilappu")
("make negation" "tee negaatio")
("make page reference" "tee sivuviite")
("make reference" "tee viite")
("make square root" "tee nelijuuri")
("make tilde" "tee tilde")
("make title" "tee otsikko")
("make vector" "tee vektori")
("making donations" "lahjoittaminen")
("manual" "manuaali")
("map to" "kuvaa")
("march" "maaliskuu")
("margins" "marginaalit")
("margins as on paper" "marginaalit kuten paperilla")
("master" "isnttiedosto")
("master file" "isnttiedosto")
("math" "matematiikka")
("math font" "matematiikkakirjasin")
("math font family" "matematiikkakirjasinperhe")
("math font series" "matematiikkakirjasinsarja")
("math font shape" "matematiikkakirjasinmuoto")
("mathematical" "matemaattinen")
("mathematical formulas" "matemaattiset kaavat")
("mathematical typesetting" "matematiikan ladonta")
("mathematics" "matematiikka")
("matrix" "matriisi")
("maximal number of columns" "sarakkeiden maksimimr")
("maximal number of rows" "rivien maksimimr")
("maximum mode" "maksimitila")
("may" "voi")
("medium" "keskisuuri")
("medium skip" "keskisuuri vli")
("meminfo" "meminfo")
("merge" "yhdist")
("messy" "messy")
("meta key" "meta-nppin")
("middle" "keskimminen")
("minimal number of columns" "sarakkeiden minimimr")
("minimal number of rows" "rivien minimimr")
("minimum mode" "miminitila")
("minus" "miinus")
("miscellaneous" "muu merkki")
("mod" "mod")
("mode" "tila")
("modifier" "muunnin")
("modify cell alignment" "muuta solun tasausta")
("modify cell border" "muuta solun reunusta")
("modify cell padding" "muuta solun tytt")
("modify cell size" "muuta solun kokoa")
("modify table border" "muuta taulukon reunusta")
("modify table padding" "muuta taulukon tytt")
("mongolian" "mongolia")
("more information about GNU TeXmacs can be found in the help" "lis tietoa GNU TeXmacsista lydt ohjeista")
("mosaic" "mosaiikki")
("move down" "siirry alas")
("move object" "siirr objektia")
("move to the right when finished" "siirry oikealle kun olet valmis")
("move up" "siirry yls")
("n-th" "n:s")
("n-th root" "n:s juuri")
("name" "nimi")
("negation" "negaatio")
("new" "uusi")
("new buffer" "uusi puskuri")
("new column" "uusi sarake")
("new item" "uusi kohta")
("new line" "uusi rivi")
("new number" "uusi numero")
("new page" "uusi sivu")
("new page before" "uusi sivu ennen")
("new paragraph" "uusi kappale")
("new roman" "new roman")
("new row" "uusi rivi")
("new table" "uusi taulukko")
("next line" "seuraava rivi")
("no changes need to be saved" "ei tallennettavia muutoksia")
("no dictionary for" "ei sanastoa")
("no first indentation" "ei ensimmist sisennyst")
("no indentation" "ei sisennyst")
("no line break" "ei rivinvaihtoa")
("no matches found" "ei tuloksia")
("no more matches for" "ei en tuloksia sanalle")
("no more redo information available" "ei lis palautettavaa")
("no more undo information available" "ei en peruutettavaa")
("no name" "ei nime")
("no page break after" "ei sivunvaihtoa jlkeen")
("no page break before" "ei sivunvaihtoa ennen")
("no spelling errors found in text" "kirjoitusvirheit ei lytynyt")
("no style" "ei tyyli")
("none" "ei mitn")
("normal" "normaali")
("not" "ei")
("not equal" "erisuuri")
("not found" "ei lytynyt")
("notation" "notaatio")
("note" "huomioitavaa")
("november" "marraskuu")
("number" "numero")
("number of columns" "sarakkeiden lukumr")
("numbered equation" "numeroitu yhtl")
("numbered equations" "numeroidut yhtlt")
("numerator" "osoittaja")
("numeric" "numeerinen")
("objectives" "tavoitteet")
("occurrences" "tapaukset")
("october" "lokakuu")
("odd page footer" "parittoman sivun alatunniste")
("odd page header" "parittoman sivun yltunniste")
("odd page margin" "parittoman sivun marginaali")
("odd page text" "parittoman sivun teksti")
("off" "pois")
("ok" "ok")
("old english" "vanha englanti")
("old slavonic" "vanha slavonia")
("old style" "vanha tyyli")
("on" "pll")
("on cells" "soluissa")
("on columns" "sarakkeissa")
("on entire table" "koko taulukossa")
("on rows" "riveiss")
("one spelling error has been corrected" "yksi kirjoitusvirhe korjattu")
("online documentation" "dokumentaatio")
("online help" "ohje")
("open" "avaa")
("open a new buffer" "avaa uusi puskuri")
("open new window" "avaa uusi ikkuna")
("opening" "aloitus")
("operation on named selection" "operaatio nimettyyn valintaan")
("operation on primary selection" "operaatio ensimmiseen valintaan")
("operation on secondary selection" "operaatio toiseen valintaan")
("operation on ternary selection" "operaatio kolmanteen valintaan")
("optical" "optinen")
("option" "asetus")
("options" "asetukset")
("or" "tai")
("orange" "oranssi")
("orientation" "suunta")
("origin" "origo")
("original welcome message" "alkuperinen tervetuloviesti")
("other" "muu")
("other pages" "muut sivut")
("other projects" "muut projektit")
("other style" "muu tyyli")
("outlined roman" "riviivallinen roman")
("over" "jakolasku")
("padding" "tytt")
("page" "sivu")
("page bottom margin" "sivun alamarginaali")
("page break" "sivunvaihto")
("page break before" "sivunvaihto ennen")
("page height" "sivun korkeus")
("page insertion" "sivun lisminen")
("page layout" "sivun asettelu")
("page reference" "sivuviite")
("page right margin" "sivun oikea marginaali")
("page top margin" "sivun ylmarginaali")
("page type" "sivun tyyppi")
("page width" "sivun leveys")
("paper" "paperi")
("paper type" "paperityyppi")
("papyrus" "papyrus")
("paragraph" "kappale")
("paragraph mode" "kappeletila")
("paragraph width" "kappeleen leveys")
("part" "osa")
("past changes" "tehdyt muutokset")
("paste" "liit")
("paste from" "liit")
("paste text" "liit teksti")
("path" "polku")
("perform operations on cells" "operoi yhteen soluun")
("perform operations on columns" "operoi sarakkeeseen")
("perform operations on entire table" "operoi koko taulukkoon")
("perform operations on rows" "operoi riviin")
("permanent" "pysyv")
("person" "henkil")
("personal dictionary has been modified" "henkilkohtaista hakemistoa on muutettu")
("phantasy" "phantasy")
("philosophy" "filosofia")
("phoenician" "foinikia")
("phonetic" "foneettinen")
("pink" "vaaleanpunainen")
("plain block" "tavallinen lohko")
("plain tabular" "tavallinen taulukoitu")
("planned changes" "suunnitellut muutokset")
("plans for the future" "tulevaisuudensuunnitelmat")
("please" "ole hyv")
("please wait" "odota")
("plus" "plus")
("polish" "puola")
("porting TeXmacs to other platforms" "TeXmacsin siirtminen muille laitealustoille")
("portrait" "pystysuora")
("portuguese" "portugali")
("position" "sijainti")
("position float" "sijoita kelluva")
("position floating object" "sijoita kelluva objekti")
("position the table" "sijoita taulukko")
("postscript" "postscript")
("postscript image" "postscript-kuva")
("pre-alpha release" "esialfa-julkaisu")
("preamble" "koodi")
("preamble mode" "kooditila")
("preferences" "asetukset")
("presentation mode" "esitystila")
("preview before printing" "esikatsele ennen tulostamista")
("preview with ghostview" "esikatselu ghostview'll")
("primary" "ensimminen")
("prime" "pilkku")
("print" "tulosta")
("print all" "tulosta kaikki")
("print all to file" "tulosta kaikki tiedostoon")
("print page selection" "tulosta valitut sivut")
("print page selection to file" "tulosta valitut sivut tiedostoon")
("print to postscript file" "tulosta postscript-tiedostoon")
("printer" "tulostin")
("printer dpi" "tulostimen dpi")
("printing command" "tulostuskomento")
("problem" "tehtv")
("professional" "ammattimainen")
("prog" "prog")
("prog font" "prog-kirjasin")
("prog font family" "prog-kirjasinperhe")
("prog font series" "prog-kirjasinsarja")
("prog font shape" "prog-kirjasinmuoto")
("program" "ohjelma")
("program mode" "ohjelmatila")
("programming" "ohjelmointi")
("progressive" "kehittyv")
("project" "projekti")
("projects" "projektit")
("prologue" "prologi")
("prompt on scripts" "kysy skripteist")
("proof" "todistus")
("proportional" "tasavlinen")
("proportional typewriter" "tasavlinen kirjoituskone")
("proposition" "propositio")
("query replace" "etsi ja korvaa")
("quit" "lopeta")
("quotation" "lainaus (quotation)")
("quote" "lainaus (quote)")
("range" "alue")
("really huge" "todella valtava")
("really quit" "lopetetaanko")
("red" "punainen")
("redo" "palauta")
("redo undone changes" "palauta peruutetut muutokset")
("reduce bottom margin by" "pienenn alamarginaalia")
("reduce left margin by" "pienenn vasenta marginaalia")
("reduce margins" "pienenn marginaaleja")
("reduce right margin by" "pienenn oikeaa marginaalia")
("reduce top margin by" "pienenn ylmarginaalia")
("reduction even page margin" "parillisen sivun marginaalin pienentminen")
("reduction odd page margin" "parittoman sivun marginaalin pienentminen")
("reduction page bottom margin" "sivun alamarginaalin pienentminen")
("reduction page right margin" "sivun oikean marginaalin pienentminen")
("reduction page top margin" "sivun ylmarginaalin pienentminen")
("reference" "viite")
("references" "viittaukset")
("regular" "tavallinen")
("release" "julkaisu")
("reload" "lataa uudelleen")
("remark" "huomautus")
("remove this switch" "poista tm valitsin")
("repeat object" "toista objekti")
("replace" "korvaa")
("replace by" "merkkijonolla")
("replaced" "korvattu")
("replaced one occurrence" "korvattiin yksi tapaus")
("reset" "nollaa")
("resize object" "muuta objektin kokoa")
("resized" "koko muutettu")
("return" "return")
("revert" "palauta")
("revert buffer" "palauta puskuri")
("right" "oikea")
("right border" "oikea reuna")
("right margin" "oikea marginaali")
("right padding" "oikea tytt")
("right aligned" "oikea reuna eptasainen")
("right subscript" "oikea alaindeksi")
("right superscript" "oikea ylindeksi")
("right surrounding" "oikea ymprist")
("rigid" "jykk")
("rigid horizontal" "jykk vaakasuora")
("rigid space" "jykk vlilynti")
("romanian" "romania")
("root" "juuri")
("rotate backward" "kierr takaperin")
("rotate forward" "kierr eteenpin")
("row" "rivi")
("row contains glued items" "rivi sislt liimattuja osia")
("runic" "riimukirjoitus")
("running author" "juokseva tekij")
("running title" "juokseva otsikko")
("russian" "venj")
("russian and Ukrainian users" "venliset ja Ukrainalaiset kyttjt")
("sample" "malli")
("sans serif" "sans serif")
("save" "talleta")
("save TeXmacs file" "talleta TeXmacs-tiedosto")
("save TeXmacs style file" "talleta TeXmacsin tyylitiedosto")
("save as" "talleta nimell")
("save as LaTeX" "talleta LaTeX-muodossa")
("save as TeX" "talleta TeX-muodossa")
("save buffer" "talleta puskuri")
("save buffer as" "talleta puskuri nimell")
("save file" "talleta tiedosto")
("save html file" "talleta html-tiedosto")
("save image" "talleta kuva")
("save latex file" "talleta LaTeX-tiedosto")
("save tex file" "talleta TeX-tiedosto")
("save this buffer" "talleta puskuri")
("save verbatim file" "talleta muotoilematon tiedosto")
("saved" "tallennettu")
("screen layout" "nytt ruudulla")
("screen margins" "marginaalit ruudulla")
("script" "skripti")
("script above" "skripti ylpuolella")
("script below" "skripti alapuolella")
("script script size" "skripti skriptin koko")
("script size" "skriptin koko")
("scripts not accepted" "skriptej ei hyvksyt")
("search" "etsi")
("searching" "etsitn")
("secondary" "toinen")
("section" "osio")
("security" "turvallisuus")
("see" "katso")
("select a document style" "valitse asiakirjan tyyli")
("select a foreground color" "valitse edustavri")
("select a language" "valitse kieli")
("selected region" "valittu alue")
("selection" "valinta")
("selections" "valinnat")
("seminar" "seminaari")
("separation between lines" "rivien vli")
("separation between paragraphs" "kappaleiden vli")
("separator" "erotin")
("september" "syyskuu")
("series" "sarja")
("series|right" "sarja|oikea")
("session" "istunto")
("session name" "istunnon nimi")
("session type" "istunnon tyyppi")
("sessions" "istunnot")
("set" "aseta")
("set background color of cell" "aseta solun taustavri")
("set cell mode" "aseta solun tila")
("set extension center" "aseta jatkeen keskus")
("set height" "aseta korkeus")
("set height of cell" "aseta solun korkeus")
("set margins" "aseta marginaalit")
("set n" "aseta n")
("set paragraph margins" "aseta kappaleen marginaalit")
("set paragraph mode" "aseta kappaletila")
("set printer dpi" "aseta tulostimen dpi")
("set printing command" "aseta tulostuskomento")
("set span" "aseta span")
("set special cell properties" "aseta solun erikoisominaisuudet")
("set special table properties" "aseta taulukon erikoisominaisuudet")
("set text width" "aseta tekstin leveys")
("set width" "aseta leveys")
("set width of cell" "aseta solun leveys")
("settings" "asetukset")
("setup printer" "asenna tulostin")
("shape" "muoto")
("shift-down" "vaihto-alas")
("shift-right" "oikea vaihto")
("show" "nyt")
("show header and footer" "nyt yl- ja alatunniste")
("show on screen" "nyt ruudulla")
("shrinking factor" "pienennystekij")
("signature" "allekirjoitus")
("size" "koko")
("size limits" "kokorajat")
("slanted" "kalteva")
("sloppy" "epmrinen")
("small" "pieni")
("small caps" "kapiteeli")
("small figure" "pieni kuva")
("small skip" "pieni vli")
("small table" "pieni taulukko")
("source code" "lhdekoodi")
("space" "vli")
("space between lines" "rivivli")
("space between paragraphs" "kappalevli")
("spacing" "vlistys")
("spanish" "espanja")
("special" "erikois")
("special cell properties" "solun erikoisominaisuudet")
("special table properties" "taulukon erikoisominaisuudet")
("specific" "koodi")
("spell" "oikolue")
("spell checking complete" "oikeinkirjoituksen tarkistus valmis")
("spelling error" "oikeinkirjoitusvirhe")
("spelling errors have been corrected" "oikeinkirjoitusvirheet on korjattu")
("split" "jaa")
("square root" "nelijuuri")
("start" "aloita")
("start a new chapter" "aloita uusi luku")
("start a new section" "aloita uusi osio")
("start an interactive session" "aloita vuorovaikutteinen istunto")
("status bar" "tilarivi")
("stretchable" "venytettv")
("stretchable horizontal" "vaakasuoraan venytettv")
("stretchable vertical" "pystysuoraan venytettv")
("stroke" "viiva")
("strokes" "viivat")
("strong" "vahva")
("structural" "rakenteellinen")
("style" "tyyli")
("styles" "tyylit")
("sub" "alamerkint")
("subparagraph" "alikappale")
("subscript" "alaindeksi")
("subsection" "alaosio")
("subsub" "ala-alamerkint")
("subsubsection" "ala-alaosio")
("summary" "yhteenveto")
("superpose" "aseta pllekin")
("superposed" "pllekin asetettu")
("superscript" "ylindeksi")
("swedish" "ruotsi")
("switch" "valitsin")
("switch to first" "vaihda ensimmiseen")
("switch to formula style" "vaihda kaavatyyliin")
("switch to last" "vaihda viimeiseen")
("switch to next" "vaihda seuraavaan")
("switch to previous" "vaihda edelliseen")
("switching and folding" "vaihtaminen ja taittaminen")
("symbol" "symboli")
("system environment variables" "jrjestelmn ympristmuuttujat")
("tab" "tabulaattori")
("table" "taulukko")
("table command" "taulukkokomento")
("table of contents" "sislt")
("tables" "taulukot")
("tabular" "taulukoitu")
("tabular material" "taulukoitu aineisto")
("teXmacs as an interface" "teXmacs kyttliittymn")
("teXmacs fonts" "teXmacsin kirjasimet")
("teXmacs notice" "teXmacs-huomautus")
("ternary" "kolmas")
("test" "testi")
("tex" "tex")
("text" "teksti")
("text font" "tekstikirjasin")
("text height correction" "tekstin korkeuden korjaaminen")
("text width" "tekstin leveys")
("texts" "tekstit")
("th century bc" ":ll vuosisadalla eaa")
("th root" ":s juuri")
("thai" "thai")
("the TeXmacs authors" "TeXmacsin tekijt")
("the application did not send its usual startup banner" "sovellus ei lhettnyt tavanomaista alkuikkunaa")
("the application does not reply" "sovellus ei vastaa")
("the application is already running" "sovellus on jo kynniss")
("the boxes produced by the typesetter" "latojan tuottamat laatikot")
("the graphical user interface" "graafinen kyttliittym")
("the leaves of TeXmacs trees" "TeXmacs-puun lehdet")
("the mycas example" "mycas-esimerkki")
("the primitive TeXmacs constructs" "TeXmacsin alkeiskonstruktiot")
("the standard TeXmacs styles" "TeXmacsin standardityylit")
("theorem" "lause")
("there are unsaved files" "kaikkia tiedostoja ei ole talletettu")
("this document has been produced using" "tm asiakirja on tehty kytten")
("this line" "tm rivi")
("this page" "tm sivu")
("tilda" "tilda")
("tilde" "tilde")
("times" "kertaa")
("tiny" "todella pieni")
("title" "otsikko")
("to the left" "vasemmalle")
("to the right" "oikealle")
("today" "tnn")
("tools" "tykalut")
("top" "yl")
("top border" "ylreuna")
("top level" "yltaso")
("top margin" "ylmarginaali")
("top padding" "ylreunan tytt")
("translate" "knn")
("tree" "puu")
("tuple" "tuple")
("turkish" "turkki")
("tutorial" "johdatus")
("type" "tyyppi")
("type a latex command followed by" "kirjoita LaTeX-komento jota seuraa")
("type body" "kirjoita runko")
("type denominator" "kirjoita nimittj")
("type numerator" "kirjoita osoittaja")
("type script" "kirjoita skripti")
("typesetted boxes" "ladotut laatikot")
("typewriter" "kirjoituskone")
("typewriter small caps" "kirjoituskonekapiteeli")
("typing a simple text" "yksinkertaisen tekstin kirjoittaminen")
("typing simple texts" "yksinkertaisten tekstien kirjoittaminen")
("ugaritic" "ugaritic")
("ukrainian" "ukraina")
("undo" "peruuta")
("undo last changes" "peruuta viimeiset muutokset")
("up" "yls")
("update" "pivit")
("update from web" "pivit verkosta")
("update image links" "pivit kuvalinkit")
("upper border" "ylreunus")
("use TeXmacs" "kyt TeXmacsia")
("use a black color" "kyt mustaa vri")
("use a blue color" "kyt sinist vri")
("use a bold font" "kyt lihvoitua kirjasinta")
("use a brown color" "kyt ruskeaa vri")
("use a calligraphic font" "kyt kalligrafista kirjasinta")
("use a green color" "kyt vihre vri")
("use a grey color" "kyt harmaata vri")
("use a magenta color" "kyt magentaa vri")
("use a orange color" "kyt oranssia vri")
("use a pink color" "kyt vaaleanpunaista vri")
("use a red color" "kyt punaista vri")
("use a sans serif font" "kyt sans-serif-kirjasinta")
("use a typewriter font" "kyt kirjoituskonekirjasinta")
("use a white color" "kyt valkoista vri")
("use a yellow color" "kyt keltaista vri")
("use blackboard bold font" "kyt blackboard bold kirjasinta")
("use bold font series" "kyt lihavoitua kirjasinsarjaa")
("use calligraphical font" "kyt kalligrafista kirjasinta")
("use footnote font size" "kyt kirjasinkokoa footnote")
("use fraktur font" "kyt fraktuura-kirjasinta")
("use huge font size" "kyt kirjasinkokoa huge")
("use italic font shape" "kyt kursiivikirjasinta")
("use large font size" "kyt kirjasinkokoa large")
("use left hand column as border" "kyt vasemmanpuoleisinta saraketta reunuksena")
("use medium font series" "kyt medium kirjasinsarjaa")
("use normal font size" "kyt kirjasinkokoa normal")
("use package" "kyt pakettia")
("use paragraph width" "kyt kappaleenleveytt")
("use really huge font size" "kyt kirjasinkokoa really huge")
("use right font shape" "kyt oikeaa kirjasinkokoa")
("use right hand column as border" "kyt oikeanpuoleista saraketta reunuksena")
("use roman font family" "kyt kirjasinperhett roman")
("use row above as border" "kyt ylpuolista rivi reunuksena")
("use row below as border" "kyt alapuolista rivi reunuksena")
("use sans serif font family" "kyt sans-serif kirjasinperhett")
("use script font size" "kyt kirjasinkokoa script")
("use slanted font shape" "kyt kirjasinmuotoa slanted")
("use small capitals" "kyt kapiteelia")
("use small font size" "kyt kirjasinkokoa small")
("use small-caps font shape" "kyt kapiteeli-kirjasinmuotoa")
("use the blackboard bold font" "kyt blackboard bold-kirjasinta")
("use the fraktur font" "kyt fraktuura-kirjasinta")
("use tiny font font size" "kyt kirjasinkokoa tiny")
("use typewriter font family" "kyt kirjoituskonekirjasinperhett")
("use very large font size" "kyt kirjasinkokoa very large")
("user manual" "kyttjn opas")
("user provided icons" "kyttjn asentamat ikonit")
("value" "value")
("variable" "muuttuja")
("variant" "variantti")
("vector" "vektori")
("verbatim" "muotoilematon")
("verse" "se")
("vertical" "pystysuora")
("vertical after" "pystysuora jlkeen")
("vertical before" "pystysuora ennen")
("vertical cell alignment" "pystysuora solun tasaus")
("vertical part" "pystysuora osa")
("vertical position" "pystysuora sijainti")
("vertical space" "pystysuora vli")
("vertical table alignment" "pystysuora taulukon tasaus")
("vertically align cell to the base" "tasaa solu vaakasuoraan alareunaan")
("vertically center the cell" "keskit solu pystysuoraan")
("very large" "erittin suuri")
("very small" "erittin pieni")
("vietnamese" "vietnam")
("view" "nyt")
("visible" "nkyv")
("warning" "varoitus")
("welcome" "tervetuloa")
("welcome to GNU TeXmacs" "tervetuloa GNU TeXmacsiin")
("what is new" "mit uutta")
("when finished" "kun valmis")
("while" "while")
("white" "valkoinen")
("wide accent" "leve aksentti")
("width" "leveys")
("width is exactly the specified width" "leveys on tsmlleen se mik on mritelty")
("width is maximum of specified width and box width" "leveys on suurempi mritellyst ja laatikon leveydest")
("width is minimum of specified width and box width" "leveys on pienempi mritellyst ja laatikon leveydest")
("width magnification" "leveyden suurennos")
("window" "ikkuna")
("window height" "ikkunan korkeus")
("window width" "ikkunan leveys")
("windows key" "windows-nppin")
("with" "with")
("write a name" "kirjoita nimi")
("write bold mathematics" "kirjoita lihavoitua matematiikkaa")
("write bold text" "kirjoita lihavoitua teksti")
("write italic text" "kirjoita kursivoitua teksti")
("write sample text" "kirjoita malliteksti")
("write strong text" "kirjoita vahvaa teksti")
("write typewriter text" "kirjoita kirjoituskoneteksti")
("write verbatim text" "kirjoita muotoilematonta teksti")
("writing data converters" "datamuuntimien tekeminen")
("writing your own style files" "omien tyylitiedostojen kirjoittaminen")
("yellow" "keltainen")
("you can also obtain" "voit mys hankkia")
("your document is back in its original state" "asiakirja on palautettu alkuperiseen tilaan")
("your first interface" "ensimminen liittymsi")
